summaryrefslogtreecommitdiffstats
path: root/src/gui/application/RosegardenGUIApp.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/application/RosegardenGUIApp.h')
-rw-r--r--src/gui/application/RosegardenGUIApp.h132
1 files changed, 66 insertions, 66 deletions
diff --git a/src/gui/application/RosegardenGUIApp.h b/src/gui/application/RosegardenGUIApp.h
index 502d195..8ae0eaa 100644
--- a/src/gui/application/RosegardenGUIApp.h
+++ b/src/gui/application/RosegardenGUIApp.h
@@ -36,18 +36,18 @@
#include "sound/AudioFile.h"
#include "sound/Midi.h"
#include <kdockwidget.h>
-#include <qstring.h>
-#include <qvaluevector.h>
-
-
-class QWidget;
-class QTimer;
-class QTextCodec;
-class QShowEvent;
-class QObject;
-class QLabel;
-class QCursor;
-class QAccel;
+#include <tqstring.h>
+#include <tqvaluevector.h>
+
+
+class TQWidget;
+class TQTimer;
+class TQTextCodec;
+class TQShowEvent;
+class TQObject;
+class TQLabel;
+class TQCursor;
+class TQAccel;
class KURL;
class KTempFile;
class KToggleAction;
@@ -123,7 +123,7 @@ public:
*/
RosegardenGUIApp(bool useSequencer = true,
bool useExistingSequencer = false,
- QObject *startupStatusMessageReceiver = 0);
+ TQObject *startupStatusMessageReceiver = 0);
virtual ~RosegardenGUIApp();
@@ -148,32 +148,32 @@ public:
/**
* open a Rosegarden file
*/
- virtual void openFile(QString filePath) { openFile(filePath, ImportCheckType); }
+ virtual void openFile(TQString filePath) { openFile(filePath, ImportCheckType); }
/**
* open a file, explicitly specifying its type
*/
- void openFile(QString filePath, ImportType type);
+ void openFile(TQString filePath, ImportType type);
/**
* decode and open a project file
*/
- void importProject(QString filePath);
+ void importProject(TQString filePath);
/**
* open a URL
*/
- virtual void openURL(QString url);
+ virtual void openURL(TQString url);
/**
* merge a file with the existing document
*/
- virtual void mergeFile(QString filePath) { mergeFile(filePath, ImportCheckType); }
+ virtual void mergeFile(TQString filePath) { mergeFile(filePath, ImportCheckType); }
/**
* merge a file, explicitly specifying its type
*/
- void mergeFile(QString filePath, ImportType type);
+ void mergeFile(TQString filePath, ImportType type);
/**
* open a URL
@@ -183,27 +183,27 @@ public:
/**
* export a MIDI file
*/
- void exportMIDIFile(QString url);
+ void exportMIDIFile(TQString url);
/**
* export a Csound scorefile
*/
- void exportCsoundFile(QString url);
+ void exportCsoundFile(TQString url);
/**
* export a Mup file
*/
- void exportMupFile(QString url);
+ void exportMupFile(TQString url);
/**
* export a LilyPond file
*/
- bool exportLilyPondFile(QString url, bool forPreview = false);
+ bool exportLilyPondFile(TQString url, bool forPreview = false);
/**
* export a MusicXml file
*/
- void exportMusicXmlFile(QString url);
+ void exportMusicXmlFile(TQString url);
/**
* Get the sequence manager object
@@ -320,17 +320,17 @@ public:
/**
* Plug a widget into our common accelerators
*/
- void plugAccelerators(QWidget *widget, QAccel *accel);
+ void plugAccelerators(TQWidget *widget, TQAccel *accel);
/**
* Override from QWidget
* Toolbars and docks need special treatment
*/
- virtual void setCursor(const QCursor&);
+ virtual void setCursor(const TQCursor&);
bool isTrackEditorPlayTracking() const;
- bool testAudioPath(QString op); // and open the dialog to set it if unset
+ bool testAudioPath(TQString op); // and open the dialog to set it if unset
bool haveAudioImporter() const { return m_haveAudioImporter; }
protected:
@@ -342,27 +342,27 @@ protected:
/**
* Create document from a file
*/
- RosegardenGUIDoc* createDocument(QString filePath, ImportType type = ImportRG4);
+ RosegardenGUIDoc* createDocument(TQString filePath, ImportType type = ImportRG4);
/**
* Create a document from RG file
*/
- RosegardenGUIDoc* createDocumentFromRGFile(QString filePath);
+ RosegardenGUIDoc* createDocumentFromRGFile(TQString filePath);
/**
* Create document from MIDI file
*/
- RosegardenGUIDoc* createDocumentFromMIDIFile(QString filePath);
+ RosegardenGUIDoc* createDocumentFromMIDIFile(TQString filePath);
/**
* Create document from RG21 file
*/
- RosegardenGUIDoc* createDocumentFromRG21File(QString filePath);
+ RosegardenGUIDoc* createDocumentFromRG21File(TQString filePath);
/**
* Create document from Hydrogen drum machine file
*/
- RosegardenGUIDoc* createDocumentFromHydrogenFile(QString filePath);
+ RosegardenGUIDoc* createDocumentFromHydrogenFile(TQString filePath);
/**/
/**/
@@ -377,7 +377,7 @@ protected:
static const void* SequencerExternal;
/// Raise the transport along
- virtual void showEvent(QShowEvent*);
+ virtual void showEvent(TQShowEvent*);
/**
* read general Options again and initialize all variables like
@@ -456,22 +456,22 @@ protected:
/**
* Create a new audio file for the sequencer and return the
* path to it as a QString.
*/
- QString createNewAudioFile();
- QValueVector<QString> createRecordAudioFiles(const QValueVector<InstrumentId> &);
+ TQString createNewAudioFile();
+ TQValueVector<TQString> createRecordAudioFiles(const TQValueVector<InstrumentId> &);
- QString getAudioFilePath();
+ TQString getAudioFilePath();
//!!!mtr
- QValueVector<InstrumentId> getArmedInstruments();
+ TQValueVector<InstrumentId> getArmedInstruments();
/**
* Show a sequencer error to the user. This is for errors from
* the framework code; the playback code uses mapped compositions
* to send these things back asynchronously.
*/
- void showError(QString error);
+ void showError(TQString error);
/*
* Return AudioManagerDialog
@@ -483,7 +483,7 @@ protected:
* good and that (if it exists) the user agrees to overwrite.
* Return a null string if the write should not go ahead.
*/
- QString getValidWriteFile(QString extension, QString label);
+ TQString getValidWriteFile(TQString extension, TQString label);
/**
* Find any non-ASCII strings in a composition that has been
@@ -495,7 +495,7 @@ protected:
* necessary).
*/
void fixTextEncodings(Composition *);
- QTextCodec *guessTextCodec(std::string);
+ TQTextCodec *guessTextCodec(std::string);
/**
* Set the current document
@@ -513,7 +513,7 @@ protected:
void createAndSetupTransport();
signals:
- void startupStatusMessage(QString message);
+ void startupStatusMessage(TQString message);
/// emitted just before the document is changed
void documentAboutToChange();
@@ -543,7 +543,7 @@ public slots:
*
* @param url : a string containing a url (protocol://foo/bar/file.rg)
*/
- virtual void slotOpenDroppedURL(QString url);
+ virtual void slotOpenDroppedURL(TQString url);
/**
* Open the document properties dialog on the Audio page
@@ -812,7 +812,7 @@ public slots:
* Tempo to Segment length
*/
void slotTempoToSegmentLength();
- void slotTempoToSegmentLength(QWidget* parent);
+ void slotTempoToSegmentLength(TQWidget* parent);
/**
* toggle segment labels
@@ -855,22 +855,22 @@ public slots:
*/
void slotEditTempo();
void slotEditTempo(timeT atTime);
- void slotEditTempo(QWidget *parent);
- void slotEditTempo(QWidget *parent, timeT atTime);
+ void slotEditTempo(TQWidget *parent);
+ void slotEditTempo(TQWidget *parent, timeT atTime);
/**
* Edit the time signature - called from a Transport signal
*/
void slotEditTimeSignature();
void slotEditTimeSignature(timeT atTime);
- void slotEditTimeSignature(QWidget *parent);
- void slotEditTimeSignature(QWidget *parent, timeT atTime);
+ void slotEditTimeSignature(TQWidget *parent);
+ void slotEditTimeSignature(TQWidget *parent, timeT atTime);
/**
* Edit the playback pointer position - called from a Transport signal
*/
void slotEditTransportTime();
- void slotEditTransportTime(QWidget *parent);
+ void slotEditTransportTime(TQWidget *parent);
/**
* Change the length of the composition
@@ -956,7 +956,7 @@ public slots:
/**
* Import Studio from File
*/
- void slotImportStudioFromFile(const QString &file);
+ void slotImportStudioFromFile(const TQString &file);
/**
* Send MIDI_RESET to all MIDI devices
@@ -1014,7 +1014,7 @@ public slots:
*
* @param text the text that is displayed in the statusbar
*/
- void slotStatusMsg(QString text);
+ void slotStatusMsg(TQString text);
/**
* changes the status message of the whole statusbar for two
@@ -1024,7 +1024,7 @@ public slots:
*
* @param text the text that is displayed in the statusbar
*/
- void slotStatusHelpMsg(QString text);
+ void slotStatusHelpMsg(TQString text);
/**
* enables/disables the transport window
@@ -1146,7 +1146,7 @@ public slots:
/**
* Put the GUI into a given Tool edit mode
*/
- void slotActivateTool(QString toolName);
+ void slotActivateTool(TQString toolName);
/**
* Toggles either the play or record metronome according
@@ -1302,8 +1302,8 @@ public slots:
*/
void slotDeleteMarker(int id,
timeT time,
- QString name,
- QString description);
+ TQString name,
+ TQString description);
/**
* Document modified
@@ -1320,7 +1320,7 @@ public slots:
* Hopefully we'll be able to get rid of this eventually,
* I should slip this in KMainWindow for KDE 4.
*/
- void slotStateChanged(QString, bool noReverse);
+ void slotStateChanged(TQString, bool noReverse);
/**
* A command has happened; check the clipboard in case we
@@ -1339,7 +1339,7 @@ public slots:
* Stop current playback, close current document,
* open specified document and play it.
*/
- void slotPlayListPlay(QString url);
+ void slotPlayListPlay(TQString url);
/**
* Call up the online tutorial
@@ -1464,7 +1464,7 @@ public slots:
* Create a plugin dialog for a given instrument and slot, or
* raise an exising one.
*/
- void slotShowPluginDialog(QWidget *parent,
+ void slotShowPluginDialog(TQWidget *parent,
InstrumentId instrument,
int index);
@@ -1489,7 +1489,7 @@ public slots:
* An external GUI has requested a program change.
*/
void slotChangePluginProgram(InstrumentId instrument,
- int index, QString program);
+ int index, TQString program);
/**
* Our internal GUI has made a program change -- the
@@ -1506,7 +1506,7 @@ public slots:
* internally.)
*/
void slotChangePluginConfiguration(InstrumentId, int index,
- bool global, QString key, QString value);
+ bool global, TQString key, TQString value);
void slotPluginDialogDestroyed(InstrumentId instrument,
int index);
void slotPluginBypassed(InstrumentId,
@@ -1534,9 +1534,9 @@ public slots:
*/
void slotEnableMIDIThruRouting();
- void slotShowToolHelp(const QString &);
+ void slotShowToolHelp(const TQString &);
- void slotNewerVersionAvailable(QString);
+ void slotNewerVersionAvailable(TQString);
void slotSetQuickMarker();
@@ -1607,7 +1607,7 @@ private:
#endif // HAVE_LIBJACK
ZoomSlider<double> *m_zoomSlider;
- QLabel *m_zoomLabel;
+ TQLabel *m_zoomLabel;
ProgressBar *m_progressBar;
@@ -1637,7 +1637,7 @@ private:
AudioPluginManager *m_pluginManager;
- QTimer* m_autoSaveTimer;
+ TQTimer* m_autoSaveTimer;
Clipboard *m_clipboard;
@@ -1666,8 +1666,8 @@ private:
// Used to fetch the current sequencer position from the mmapped sequencer information file
//
- QTimer *m_playTimer;
- QTimer *m_stopTimer;
+ TQTimer *m_playTimer;
+ TQTimer *m_stopTimer;
StartupTester *m_startupTester;
@@ -456,22 +456,22 @@ protected:
/**
* Create a new audio file for the sequencer and return the
- * path to it as a QString.
+ * path to it as a TQString.
*/